@@ -16,6 +16,8 @@ from __future__ import print_function
 from __future__ import unicode_literals
 
 import caniusepython3 as ciu
+from caniusepython3 import pypi
+from caniusepython3 import dependencies
 
 import distlib.metadata
 import pip.req
@@ -26,30 +28,34 @@ import logging
 import sys
 
 
-def projects_from_requirements(requirements_path):
+def projects_from_requirements(requirements):
     """Extract the project dependencies from a Requirements specification."""
     log = logging.getLogger('ciu')
-    reqs = pip.req.parse_requirements(requirements_path)
     valid_reqs = []
-    for req in reqs:
-        if not req.name:
-            log.warning('A requirement lacks a name '
-                        '(e.g. no `#egg` on a `file:` path)')
-        elif req.editable:
-            log.warning(
-                'Skipping {0}: editable projects unsupported'.format(req.name))
-        elif req.url and req.url.startswith('file:'):
-            log.warning(
-                'Skipping {0}: file-specified projects unsupported'.format(req.name))
-        else:
-            valid_reqs.append(req.name)
+    for requirements_path in requirements:
+        reqs = pip.req.parse_requirements(requirements_path)
+        for req in reqs:
+            if not req.name:
+                log.warning('A requirement lacks a name '
+                            '(e.g. no `#egg` on a `file:` path)')
+            elif req.editable:
+                log.warning(
+                    'Skipping {0}: editable projects unsupported'.format(req.name))
+            elif req.url and req.url.startswith('file:'):
+                log.warning(
+                    'Skipping {0}: file-specified projects unsupported'.format(req.name))
+            else:
+                valid_reqs.append(req.name)
     return valid_reqs
 
 
 def projects_from_metadata(metadata):
     """Extract the project dependencies from a metadata spec."""
-    meta = distlib.metadata.Metadata(fileobj=io.StringIO(metadata))
-    return [ciu.just_name(project) for project in meta.run_requires]
+    projects = []
+    for data in metadata:
+        meta = distlib.metadata.Metadata(fileobj=io.StringIO(data))
+        projects.extend(pypi.just_name(project) for project in meta.run_requires)
+    return projects
 
 
 def projects_from_cli(args):
@@ -57,14 +63,14 @@ def projects_from_cli(args):
     description = ('Determine if a set of project dependencies will work with '
                    'Python 3')
     parser = argparse.ArgumentParser(description=description)
-    req_help = ('path to a pip requirements file (e.g. requirements.txt)')
-    parser.add_argument('--requirements', '-r', nargs='?',
+    req_help = 'path(s) to a pip requirements file (e.g. requirements.txt)'
+    parser.add_argument('--requirements', '-r', nargs='+', default=(),
                         help=req_help)
-    meta_help = 'path to a PEP 426 metadata file (e.g. PKG-INFO, pydist.json)'
-    parser.add_argument('--metadata', '-m', nargs='?',
+    meta_help = 'path(s) to a PEP 426 metadata file (e.g. PKG-INFO, pydist.json)'
+    parser.add_argument('--metadata', '-m', nargs='+', default=(),
                         help=meta_help)
-    parser.add_argument('--projects', '-p', type=lambda arg: arg.split(','),
-                        nargs='?', help='a comma-separated list of projects')
+    parser.add_argument('--projects', '-p', nargs='+', default=(),
+                        help='name(s) of projects to test for Python 3 support')
     parser.add_argument('--verbose', '-v', action='store_true',
                         help='verbose output')
     parsed = parser.parse_args(args)
@@ -75,13 +81,13 @@ def projects_from_cli(args):
     projects = []
     if parsed.verbose:
         logging.getLogger('ciu').setLevel(logging.INFO)
-    if parsed.requirements:
-        projects.extend(projects_from_requirements(parsed.requirements))
-    if parsed.metadata:
-        with io.open(parsed.metadata) as file:
-            projects.extend(projects_from_metadata(file.read()))
-    if parsed.projects:
-        projects.extend(parsed.projects)
+    projects.extend(projects_from_requirements(parsed.requirements))
+    metadata = []
+    for metadata_path in parsed.metadata:
+        with io.open(metadata_path) as file:
+            metadata.append(file.read())
+    projects.extend(projects_from_metadata(metadata))
+    projects.extend(parsed.projects)
 
     return projects
 
@@ -134,7 +140,7 @@ def check(projects):
     log = logging.getLogger('ciu')
     log.info('{0} top-level projects to check'.format(len(projects)))
     print('Finding and checking dependencies ...')
-    blockers = ciu.blocking_dependencies(projects, ciu.all_py3_projects())
+    blockers = dependencies.blocking_dependencies(projects, pypi.all_py3_projects())
 
     print('')
     for line in message(blockers):
@@ -149,5 +155,5 @@ def main(args=sys.argv[1:]):
     check(projects_from_cli(args))
 
 
-if __name__ == '__main__':
+if __name__ == '__main__':  #pragma: no cover
     main()
